@@ -20,12 +20,14 @@ test_that("stouffer() works correctly with effective number of tests.", {
   res_lj  <- stouffer(grid2ip.p, adjust = "liji", R = mvnconv(grid2ip.ld, target = "p", cov2cor = TRUE))
   res_gao <- stouffer(grid2ip.p, adjust = "gao", R = mvnconv(grid2ip.ld, target = "p", cov2cor = TRUE))
   res_gal <- stouffer(grid2ip.p, adjust = "galwey", R = mvnconv(grid2ip.ld, target = "p", cov2cor = TRUE))
+  res_che <- stouffer(grid2ip.p, adjust = "chen", R = mvnconv(grid2ip.ld, target = "p", cov2cor = TRUE))
   res_user <- stouffer(grid2ip.p, m = 18)
 
   out <- capture.output(print(res_nyh))
   out <- capture.output(print(res_lj))
   out <- capture.output(print(res_gao))
   out <- capture.output(print(res_gal))
+  out <- capture.output(print(res_che))
   out <- capture.output(print(res_user))
 
   expect_equivalent(c(res_nyh$p), 3.617704e-09, tolerance = p_tol)
@@ -40,6 +42,9 @@ test_that("stouffer() works correctly with effective number of tests.", {
   expect_equivalent(c(res_gal$p), 1.732717e-08, tolerance = p_tol)
   expect_equivalent(c(res_gal$statistic), 5.516131, tolerance = stat_tol)
 
+  expect_equivalent(c(res_che$p), 3.617704e-09, tolerance = p_tol)
+  expect_equivalent(c(res_che$statistic), 5.785367, tolerance = stat_tol)
+
   expect_equivalent(c(res_user$p), 8.336258e-08, tolerance = p_tol)
   expect_equivalent(c(res_user$statistic), 5.233062, tolerance = stat_tol)
 
